@@ -15,9 +15,11 @@
 # limitations under the License.
 #
 
-from typing import Callable, Dict, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple
 
 from google.api_core import grpc_helpers  # type: ignore
+from google.api_core import gapic_v1  # type: ignore
+from google import auth  # type: ignore
 from google.auth import credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
@@ -28,7 +30,7 @@ from google.cloud.bigquery.reservation_v1.types import reservation
 from google.cloud.bigquery.reservation_v1.types import reservation as gcbr_reservation
 from google.protobuf import empty_pb2 as empty  # type: ignore
 
-from .base import ReservationServiceTransport
+from .base import ReservationServiceTransport, DEFAULT_CLIENT_INFO
 
 
 class ReservationServiceGrpcTransport(ReservationServiceTransport):
@@ -60,14 +62,20 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
     top of HTTP/2); the ``grpcio`` package must be installed.
     """
 
+    _stubs: Dict[str, Callable]
+
     def __init__(
         self,
         *,
         host: str = "bigqueryreservation.googleapis.com",
         credentials: credentials.Credentials = None,
+        credentials_file: str = None,
+        scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
         api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None
+        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
+        quota_project_id: Optional[str] = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the transport.
 
@@ -79,6 +87,11 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
                 This argument is ignored if ``channel`` is provided.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is ignored if ``channel`` is provided.
+            scopes (Optional(Sequence[str])): A list of scopes. This argument is
+                ignored if ``channel`` is provided.
             channel (Optional[grpc.Channel]): A ``Channel`` instance through
                 which to make calls.
             api_mtls_endpoint (Optional[str]): The mutual TLS endpoint. If
@@ -89,10 +102,19 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
                 callback to provide client SSL certificate bytes and private key
                 bytes, both in PEM format. It is ignored if ``api_mtls_endpoint``
                 is None.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
+                The client info used to send a user-agent string along with	
+                API requests. If ``None``, then default info will be used.	
+                Generally, you only need to set this if you're developing	
+                your own client library.
 
         Raises:
-          google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
+          google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
               creation failed for any reason.
+          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
+              and ``credentials_file`` are passed.
         """
         if channel:
             # Sanity check: Ensure that channel and credentials are not both
@@ -108,6 +130,11 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
                 else api_mtls_endpoint + ":443"
             )
 
+            if credentials is None:
+                credentials, _ = auth.default(
+                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
+                )
+
             # Create SSL credentials with client_cert_source or application
             # default SSL credentials.
             if client_cert_source:
@@ -119,23 +146,36 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
                 ssl_credentials = SslCredentials().ssl_credentials
 
             # create a new channel. The provided one is ignored.
-            self._grpc_channel = grpc_helpers.create_channel(
+            self._grpc_channel = type(self).create_channel(
                 host,
                 credentials=credentials,
+                credentials_file=credentials_file,
                 ssl_credentials=ssl_credentials,
-                scopes=self.AUTH_SCOPES,
+                scopes=scopes or self.AUTH_SCOPES,
+                quota_project_id=quota_project_id,
             )
 
-        # Run the base constructor.
-        super().__init__(host=host, credentials=credentials)
         self._stubs = {}  # type: Dict[str, Callable]
 
+        # Run the base constructor.
+        super().__init__(
+            host=host,
+            credentials=credentials,
+            credentials_file=credentials_file,
+            scopes=scopes or self.AUTH_SCOPES,
+            quota_project_id=quota_project_id,
+            client_info=client_info,
+        )
+
     @classmethod
     def create_channel(
         cls,
         host: str = "bigqueryreservation.googleapis.com",
         credentials: credentials.Credentials = None,
-        **kwargs
+        credentials_file: str = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
+        **kwargs,
     ) -> grpc.Channel:
         """Create and return a gRPC channel object.
         Args:
@@ -145,13 +185,31 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
                 credentials identify this application to the service. If
                 none are specified, the client will attempt to ascertain
                 the credentials from the environment.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is mutually exclusive with credentials.
+            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
+                service. These are only used when credentials are not specified and
+                are passed to :func:`google.auth.default`.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
             kwargs (Optional[dict]): Keyword arguments, which are passed to the
                 channel creation.
         Returns:
             grpc.Channel: A gRPC channel object.
+
+        Raises:
+            google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
+              and ``credentials_file`` are passed.
         """
+        scopes = scopes or cls.AUTH_SCOPES
         return grpc_helpers.create_channel(
-            host, credentials=credentials, scopes=cls.AUTH_SCOPES, **kwargs
+            host,
+            credentials=credentials,
+            credentials_file=credentials_file,
+            scopes=scopes,
+            quota_project_id=quota_project_id,
+            **kwargs,
         )
 
     @property
@@ -165,7 +223,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
         # have one.
         if not hasattr(self, "_grpc_channel"):
             self._grpc_channel = self.create_channel(
-                self._host, credentials=self._credentials
+                self._host, credentials=self._credentials,
             )
 
         # Return the channel from cache.
@@ -173,7 +231,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def create_reservation(
-        self
+        self,
     ) -> Callable[
         [gcbr_reservation.CreateReservationRequest], gcbr_reservation.Reservation
     ]:
@@ -201,7 +259,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def list_reservations(
-        self
+        self,
     ) -> Callable[
         [reservation.ListReservationsRequest], reservation.ListReservationsResponse
     ]:
@@ -230,7 +288,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def get_reservation(
-        self
+        self,
     ) -> Callable[[reservation.GetReservationRequest], reservation.Reservation]:
         r"""Return a callable for the get reservation method over gRPC.
 
@@ -256,7 +314,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def delete_reservation(
-        self
+        self,
     ) -> Callable[[reservation.DeleteReservationRequest], empty.Empty]:
         r"""Return a callable for the delete reservation method over gRPC.
 
@@ -284,7 +342,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def update_reservation(
-        self
+        self,
     ) -> Callable[
         [gcbr_reservation.UpdateReservationRequest], gcbr_reservation.Reservation
     ]:
@@ -312,7 +370,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def create_capacity_commitment(
-        self
+        self,
     ) -> Callable[
         [reservation.CreateCapacityCommitmentRequest], reservation.CapacityCommitment
     ]:
@@ -340,7 +398,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def list_capacity_commitments(
-        self
+        self,
     ) -> Callable[
         [reservation.ListCapacityCommitmentsRequest],
         reservation.ListCapacityCommitmentsResponse,
@@ -370,7 +428,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def get_capacity_commitment(
-        self
+        self,
     ) -> Callable[
         [reservation.GetCapacityCommitmentRequest], reservation.CapacityCommitment
     ]:
@@ -398,7 +456,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def delete_capacity_commitment(
-        self
+        self,
     ) -> Callable[[reservation.DeleteCapacityCommitmentRequest], empty.Empty]:
         r"""Return a callable for the delete capacity commitment method over gRPC.
 
@@ -426,7 +484,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def update_capacity_commitment(
-        self
+        self,
     ) -> Callable[
         [reservation.UpdateCapacityCommitmentRequest], reservation.CapacityCommitment
     ]:
@@ -461,7 +519,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def split_capacity_commitment(
-        self
+        self,
     ) -> Callable[
         [reservation.SplitCapacityCommitmentRequest],
         reservation.SplitCapacityCommitmentResponse,
@@ -498,7 +556,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def merge_capacity_commitments(
-        self
+        self,
     ) -> Callable[
         [reservation.MergeCapacityCommitmentsRequest], reservation.CapacityCommitment
     ]:
@@ -535,7 +593,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def create_assignment(
-        self
+        self,
     ) -> Callable[[reservation.CreateAssignmentRequest], reservation.Assignment]:
         r"""Return a callable for the create assignment method over gRPC.
 
@@ -592,7 +650,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def list_assignments(
-        self
+        self,
     ) -> Callable[
         [reservation.ListAssignmentsRequest], reservation.ListAssignmentsResponse
     ]:
@@ -641,7 +699,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def delete_assignment(
-        self
+        self,
     ) -> Callable[[reservation.DeleteAssignmentRequest], empty.Empty]:
         r"""Return a callable for the delete assignment method over gRPC.
 
@@ -682,7 +740,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def search_assignments(
-        self
+        self,
     ) -> Callable[
         [reservation.SearchAssignmentsRequest], reservation.SearchAssignmentsResponse
     ]:
@@ -734,7 +792,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def move_assignment(
-        self
+        self,
     ) -> Callable[[reservation.MoveAssignmentRequest], reservation.Assignment]:
         r"""Return a callable for the move assignment method over gRPC.
 
@@ -764,7 +822,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def get_bi_reservation(
-        self
+        self,
     ) -> Callable[[reservation.GetBiReservationRequest], reservation.BiReservation]:
         r"""Return a callable for the get bi reservation method over gRPC.
 
@@ -790,7 +848,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def update_bi_reservation(
-        self
+        self,
     ) -> Callable[[reservation.UpdateBiReservationRequest], reservation.BiReservation]:
         r"""Return a callable for the update bi reservation method over gRPC.
 
